@@ -1,10 +1,8 @@
 import pytest
-from sqlmodel import SQLModel
 
 from fastapi_user_auth.auth.backends.db import DbTokenStore
 from fastapi_user_auth.auth.backends.jwt import JwtTokenStore
 from fastapi_user_auth.auth.schemas import BaseTokenData
-from tests.test_auth.db import get_db
 
 token_data = BaseTokenData(id=1, username='test')
 
@@ -21,10 +19,7 @@ async def test_jwt_token_store():
 
 
 @pytest.mark.asyncio
-async def test_db_token_store():
-    db = get_db()
-    async with db.engine.begin() as conn:
-        await conn.run_sync(SQLModel.metadata.create_all)
+async def test_db_token_store(db):
     store = DbTokenStore(db)
     token = await store.write_token(token_data)
     assert token
